==> piwigo-2.1.6.zip: piwigo/language/ar_SA/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'تحديث';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'معالجة التحديث يقترح تحديث قاعدة البيانات القديمة الخاصة بـ Piwigo من الاصدار القديم إلى الاصدار الجديد . مساعد الترقية يتعقد انك جاليا ً تشغل<strong> %s الأصدار </strong> ( أو ما يعادلها ).';
$lang['Upgrade from version %s to %s'] = '%s إلى %s التحديث من الأصدار';
$lang['Statistics'] = 'إحصاءات';
$lang['total upgrade time'] = 'الوقت الذي يحتاجه التحديث';
$lang['total SQL time'] = 'الوقت الذي يجتاجه المزو SQL';
$lang['SQL queries'] = ' SQLمزود الاستعلامات';
$lang['Upgrade informations'] = 'ترقية المعلومات ';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'للفحص والتدقيق والصيانى  [الإدارة>أدوات>الصيانة] إذا واجهتك أي مشكلة  ';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'كأجراء وقائي يجب تعطيل الاضافات ، كما ينبغي التأكد من وجود تحديثات جديدة لهذه الاضافات';
$lang['Only administrator can run upgrade: please sign in below.'] = 'فقط يمكن للمسؤول تشغيل الترقية : الرجاء تسجيل الدخول أدناه.';
$lang['You do not have access rights to run upgrade'] = 'ليس لديك حقق الوصول  في تشغيل الترقية';
$lang['All sub-albums of private albums become private'] = 'جميع البومات الفرعية من الألبومات الخاصة أصبحت خاصة';
$lang['User permissions and group permissions have been erased'] = 'تم مسح للمستخدمين وأذونات المجموعات';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'تم حفظ بدائة الصور المصغرة ، و عنواين مدير الموقع حفظت من التكوين السابق';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'في <i>%s</i>, قبل <b>?></b>, إدراج:';

?>

==> piwigo-2.5.1.zip: piwigo/language/ar_SA/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'تحديث';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'معالجة التحديث يقترح تحديث قاعدة البيانات القديمة الخاصة بـ Piwigo من الاصدار القديم إلى الاصدار الجديد . مساعد الترقية يتعقد انك جاليا ً تشغل<strong> %s الأصدار </strong> ( أو ما يعادلها ).';
$lang['Upgrade from version %s to %s'] = '%s إلى %s التحديث من الأصدار';
$lang['Statistics'] = 'إحصاءات';
$lang['total upgrade time'] = 'الوقت الذي يحتاجه التحديث';
$lang['total SQL time'] = 'الوقت الذي يجتاجه المزو SQL';
$lang['SQL queries'] = ' SQLمزود الاستعلامات';
$lang['Upgrade informations'] = 'ترقية المعلومات ';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'للفحص والتدقيق والصيانى  [الإدارة>أدوات>الصيانة] إذا واجهتك أي مشكلة  ';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'كأجراء وقائي يجب تعطيل الاضافات ، كما ينبغي التأكد من وجود تحديثات جديدة لهذه الاضافات';
$lang['Only administrator can run upgrade: please sign in below.'] = 'فقط يمكن للمسؤول تشغيل الترقية : الرجاء تسجيل الدخول أدناه.';
$lang['You do not have access rights to run upgrade'] = 'ليس لديك حقق الوصول  في تشغيل الترقية';
$lang['All sub-albums of private albums become private'] = 'جميع البومات الفرعية من الألبومات الخاصة أصبحت خاصة';
$lang['User permissions and group permissions have been erased'] = 'تم مسح للمستخدمين وأذونات المجموعات';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'تم حفظ بدائة الصور المصغرة ، و عنواين مدير الموقع حفظت من التكوين السابق';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'في <i>%s</i>, قبل <b>?></b>, إدراج:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'للاحتياط,الثيمات التالية تم الغاء تفعيلها.يجب ان تقوم بعملية تحديث للثيمات قبل تفعيلها';

?>
